import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import { Table, Input, Select, Pagination, Radio, Icon } from 'antd';
import styles from './AXSingleSelectTable.less';

function addRowKey(data) {
  return data.map((item) => {
    return {
      ...item,
      key: item.id,
    };
  });
}
const options = [{
  text: '编号',
  value: 'code',
}, {
  text: '名称',
  value: 'name',
}];

export default class AXSingleSelectTable extends PureComponent {
  static propTypes = {
    dataSource: PropTypes.array,
    loading: PropTypes.bool,
    columns: PropTypes.array,
    pagination: PropTypes.object,
  };
  static defaultProps = {
    dataSource: [],
    loading: false,
    columns: [],
    pagination: {},
  };
  constructor(props) {
    super(props);
    this.state = {
      selectRowKey: props.value,
      searchSelectKey: 'code',
      searchInputValue: '',
      selectRowName: props.currentName,
    };
  }
  componentWillReceiveProps(nextProps) {
    const stateProps = {};
    if (nextProps.value && (nextProps.value !== this.props.value)) {
      stateProps.selectRowKey = nextProps.value;
    }
    if (nextProps.currentName && (nextProps.currentName !== this.props.currentName)) {
      stateProps.selectRowName = nextProps.currentName;
    }
    this.setState({ ...stateProps });
  }
  getListHeader = () => {
    const { pagination } = this.props;
    const paginationProps = {
      current: pagination.pageNo,
      pageSize: pagination.pageSize,
      total: pagination.totalSize,
      onChange: this.handleListPageChange,
      showTotal: total => `共 ${total} 条`,
    };
    return (
      <div className={styles.header}>
        <div className={styles.headerSearch}>
          <div className={styles.searchPage}>
            <div className={styles.left}>
              <Input.Search
                enterButton
                placeholder="请输入"
                style={{ width: '75%' }}
                addonBefore={
                  <Select
                    placeholder="请选择"
                    value={this.state.searchSelectKey}
                    onChange={this.handleSelectChange}
                  >
                    {options.map(item => (
                      <Select.Option
                        key={item.value}
                        value={item.value}
                      >
                        {item.text}
                      </Select.Option>))}
                  </Select>
                }
                value={this.state.searchInputValue}
                onChange={this.handleInputChange}
                onSearch={this.handleSearchBtnClick}
              />
            </div>
            <div className={styles.right}>
              <Pagination {...paginationProps} />
            </div>
          </div>
        </div>
      </div>
    );
  };
  getListFooter = () => {
    if (!this.state.selectRowKey) {
      return (
        <span>
          <span className={styles.label}>当前已选：</span>
          <span className={styles.notSelect}>
            未选择<Icon type="frown" />
          </span>
        </span>
      );
    }
    return (
      <span>
        <span className={styles.label}>当前已选：</span>
        <span className={styles.selected}>
          {this.state.selectRowName}
        </span>
      </span>
    );
  };
  handleSelectChange = (value) => {
    this.setState({ searchSelectKey: value });
  };
  handleInputChange = (e) => {
    this.setState({ searchInputValue: e.target.value });
  };
  handleFilterOperation = (kv) => {
    const { searchSelectKey, searchInputValue } = this.state;
    this.props.onFilterClick({
      [searchSelectKey]: searchInputValue,
      ...kv,
    });
  };
  handleOnRowClick = (record) => {
    this.setState({
      selectRowKey: record.key,
      selectRowName: record.name,
    });
    if (this.props.onChange) {
      this.props.onChange(record);
    }
  };
  handleSearchBtnClick = () => {
    this.handleFilterOperation();
  };
  handleListPageChange = (page, pageSize) => {
    this.handleFilterOperation({
      pageSize,
      pageNo: page,
    });
  };

  render() {
    const { columns, dataSource, loading } = this.props;
    const addColumnOnFirst = (cols) => {
      const newColumns = [...cols];
      newColumns.unshift({
        key: '-1',
        dataIndex: 'key',
        width: 20,
        render: (text) => {
          return (
            <Radio
              key={text}
              checked={this.state.selectRowKey === text}
            />
          );
        },
      });
      return newColumns;
    };
    const onRowClick = (record) => {
      return {
        onClick: () => this.handleOnRowClick(record),
      };
    };
    return (
      <Table
        bordered={false}
        loading={loading}
        columns={addColumnOnFirst(columns)}
        title={this.getListHeader}
        footer={this.getListFooter}
        className={styles.table}
        rowKey={record => record.key}
        onRow={onRowClick}
        dataSource={addRowKey(dataSource)}
        pagination={false}
      />
    );
  }
}
