import { message } from 'antd';
import { routerRedux } from 'dva/router';
import {
  createItem,
  deleteItem,
  recoverItem,
  queryItemList,
  queryItemDetail,
  createItemPrice,
  updateItemPrice,
  deleteItemPrice,
  updateItemTags,
} from '../services/shelves';
import { Hotax } from '../utils/config';

export default {
  namespace: 'shelves',

  state: {
    list: [],
    pageNo: 1,
    pageSize: 15,
    totalSize: 0,
    currentItem: {},
  },

  effects: {
    *fetchItemList({ payload }, { call, put }) {
      const response = yield call(queryItemList, payload);
      if (response.success) {
        yield put({
          type: 'querySuccess',
          payload: {
            list: response.data.list || [],
            pageSize: response.data.pageSize,
            totalSize: response.data.totalSize,
            pageNo: response.data.pageNo,
          },
        });
      }
    },
    *fetchCourseItemList({ payload }, { call, put }) {
      const response = yield call(queryItemList, { type: Hotax.PRODUCT_COURSE, ...payload });
      if (response.success) {
        yield put({
          type: 'querySuccess',
          payload: {
            list: response.data.list || [],
            pageSize: response.data.pageSize,
            totalSize: response.data.totalSize,
            pageNo: response.data.pageNo,
          },
        });
      }
    },
    *fetchSupportItemList({ payload }, { call, put }) {
      const response = yield call(queryItemList, { type: Hotax.PRODUCT_SUPPORT, ...payload });
      if (response.success) {
        yield put({
          type: 'querySuccess',
          payload: {
            list: response.data.list || [],
            pageSize: response.data.pageSize,
            totalSize: response.data.totalSize,
            pageNo: response.data.pageNo,
          },
        });
      }
    },
    *fetchTrainingItemList({ payload }, { call, put }) {
      const response = yield call(queryItemList, { type: Hotax.PRODUCT_TRAINING, ...payload });
      if (response.success) {
        yield put({
          type: 'querySuccess',
          payload: {
            list: response.data.list || [],
            pageSize: response.data.pageSize,
            totalSize: response.data.totalSize,
            pageNo: response.data.pageNo,
          },
        });
      }
    },
    *fetchPackageItemList({ payload }, { call, put }) {
      const response = yield call(queryItemList, { type: Hotax.PRODUCT_PACKAGE, ...payload });
      if (response.success) {
        yield put({
          type: 'querySuccess',
          payload: {
            list: response.data.list || [],
            pageSize: response.data.pageSize,
            totalSize: response.data.totalSize,
            pageNo: response.data.pageNo,
          },
        });
      }
    },
    *fetchItemDetail({ payload }, { call, put }) {
      const response = yield call(queryItemDetail, payload);
      if (response.success) {
        yield put({
          type: 'querySuccess',
          payload: {
            currentItem: response.data || {},
          },
        });
      }
    },
    *createItem({ payload, states }, { call, put }) {
      const { itemType, ...restState } = states;
      const response = yield call(createItem, payload);
      if (response.success) {
        message.success('上架成功');
        yield put(routerRedux.push({
          pathname: `/shelves/${itemType}`,
          state: restState,
        }));
      }
    },
    *deleteItem({ payload, states }, { call, put }) {
      const response = yield call(deleteItem, payload);
      if (response.success) {
        message.success('下架成功');
        const { scene, Queryers } = states;
        yield put({
          type: `fetch${scene}ItemList`,
          payload: Queryers,
        });
      }
    },
    *recoverItem({ payload, states }, { call, put }) {
      const response = yield call(recoverItem, payload);
      if (response.success) {
        const { scene, Queryers } = states;
        message.success('上架成功');
        yield put({
          type: `fetch${scene}ItemList`,
          payload: Queryers,
        });
      }
    },
    *createItemPrice({ payload, states }, { call, put }) {
      const response = yield call(createItemPrice, payload);
      if (response.success) {
        message.success('添加价格成功');
        yield put({
          type: 'fetchItemDetail',
          payload: states,
        });
      }
    },
    *updateItemPrice({ payload, states }, { call, put }) {
      const response = yield call(updateItemPrice, payload);
      if (response.success) {
        message.success('修改价格成功');
        yield put({
          type: 'fetchItemDetail',
          payload: states,
        });
      }
    },
    *deleteItemPrice({ payload, states }, { call, put }) {
      const response = yield call(deleteItemPrice, payload);
      if (response.success) {
        message.success('删除价格成功');
        yield put({
          type: 'fetchItemDetail',
          payload: states,
        });
      }
    },
    *updateItemTags({ payload, states }, { call, put }) {
      const response = yield call(updateItemTags, payload);
      if (response.success) {
        message.success('修改上架栏目成功');
        yield put({
          type: 'fetchItemDetail',
          payload: states,
        });
      }
    },
  },

  reducers: {
    querySuccess(state, action) {
      return {
        ...state,
        ...action.payload,
      };
    },
    cleanListState(state) {
      return {
        ...state,
        list: [],
        pageSize: 15,
        pageNo: 1,
      };
    },
    cleanItemState(state) {
      return {
        ...state,
        currentItem: {},
      };
    },
    fixCurrentItem(state, action) {
      const { currentItem } = state;
      return {
        ...state,
        currentItem: {
          ...currentItem,
          ...action.payload,
        },
      };
    },
  },
};
