import { message } from 'antd';
import { routerRedux } from 'dva/router';
import {
  deviceUnbound,
  queryTerminalList,
  createTerminalItem,
  updateTerminalItem,
  deleteTerminalItem,
  querySpecialTerminalList,
  querySpecialTerminalItem,
  createSpecialTerminalItem,
  updateSpecialTerminalItem,
  deleteSpecialTerminalItem,
  queryTerminalAuthList,
} from '../services/terminal';

export default {
  namespace: 'terminal',

  state: {
    list: [],
    pageNo: 1,
    pageSize: 15,
    totalSize: 0,
    currentItem: {},
  },

  effects: {
    *fetchTerminalList({ payload }, { call, put }) {
      const response = yield call(queryTerminalList, payload);
      if (response.success) {
        yield put({
          type: 'querySuccess',
          payload: {
            list: response.data.list || [],
            pageSize: response.data.pageSize,
            totalSize: response.data.totalSize,
            pageNo: response.data.pageNo,
          },
        });
      }
    },
    *createTerminalItem({ payload, state }, { call, put }) {
      const response = yield call(createTerminalItem, payload);
      if (response.success) {
        message.success('创建终端成功');
        yield put(routerRedux.push({
          state,
          pathname: '/terminal/user/list',
        }));
      }
    },
    *deleteTerminalItem({ payload, states }, { call, put }) {
      const response = yield call(deleteTerminalItem, payload);
      if (response.success) {
        message.success('禁用终端成功');
        yield put({
          type: 'fetchTerminalList',
          payload: states.Queryers,
        });
      }
    },
    *recoverTerminalItem({ payload, states }, { call, put }) {
      const response = yield call(updateTerminalItem, payload);
      if (response.success) {
        message.success('解禁终端成功');
        yield put({
          type: 'fetchTerminalList',
          payload: states.Queryers,
        });
      }
    },
    *updateTerminalItem({ payload, states }, { call, put }) {
      const response = yield call(updateTerminalItem, payload);
      if (response.success) {
        message.success('修改终端成功');
        yield put(routerRedux.push({
          pathname: '/terminal/user/list',
          state: states,
        }));
      }
    },
    *fetchSpecialTerminalList({ payload }, { call, put }) {
      const response = yield call(querySpecialTerminalList, payload);
      if (response.success) {
        yield put({
          type: 'querySuccess',
          payload: {
            list: response.data.list || [],
            pageSize: response.data.pageSize,
            totalSize: response.data.totalSize,
            pageNo: response.data.pageNo,
          },
        });
      }
    },
    *fetchSpecialTerminalItem({ payload }, { call, put }) {
      const response = yield call(querySpecialTerminalItem, payload);
      if (response.success) {
        yield put({
          type: 'querySuccess',
          payload: {
            currentItem: response.data,
          },
        });
      }
    },
    *createSpecialTerminalItem({ payload, states }, { call, put }) {
      const response = yield call(createSpecialTerminalItem, payload);
      if (response.success) {
        message.success('创建白名单用户成功');
        yield put(routerRedux.push({
          state: states,
          pathname: '/terminal/whitelist/list',
        }));
      }
    },
    *deleteSpecialTerminalItem({ payload, states }, { call, put }) {
      const response = yield call(deleteSpecialTerminalItem, payload);
      if (response.success) {
        message.success('删除白名单用户成功');
        yield put({
          type: 'fetchSpecialTerminalList',
          payload: states.Queryers,
        });
      }
    },
    *updateSpecialTerminalItem({ payload, states }, { call, put }) {
      const response = yield call(updateSpecialTerminalItem, payload);
      if (response.success) {
        message.success('修改白名单用户成功');
        yield put(routerRedux.push({
          pathname: '/terminal/whitelist/list',
          state: states,
        }));
      }
    },
    *deviceUnbound({ payload, states }, { call, put }) {
      const response = yield call(deviceUnbound, payload);
      if (response.success) {
        message.success('账号已成功解绑');
        yield put({
          type: 'fetchTerminalList',
          payload: states.Queryers,
        });
      }
    },
    *fetchTerminalAuthList({ payload }, { call, put }) {
      const response = yield call(queryTerminalAuthList, payload);
      if (response.success) {
        yield put({
          type: 'querySuccess',
          payload: {
            list: response.data.list || [],
            pageSize: response.data.pageSize,
            totalSize: response.data.totalSize,
            pageNo: response.data.pageNo,
          },
        });
      }
    },
  },

  reducers: {
    querySuccess(state, action) {
      return {
        ...state,
        ...action.payload,
      };
    },
    fixCurrentItem(state, action) {
      const { currentItem } = state;
      return {
        ...state,
        currentItem: {
          ...currentItem,
          ...action.payload,
        },
      };
    },
    cleanState(state) {
      return {
        ...state,
        currentItem: {},
        list: [],
        pageNo: 1,
        pageSize: 15,
        totalSize: 0,
      };
    },
  },
};
