import React, { Component } from 'react';
import moment from 'moment';
import { connect } from 'dva';
import { Card, message } from 'antd';
import { StandardTableList } from '../../components/AXList';
import { addRowKey, renderProductType } from '../../utils/utils';
import styles from './SnapshopList.less';

const Message = message;

@connect(({ trade, loading }) => ({
  trade,
  loading: loading.models.trade,
}))
export default class SnapshotListPage extends Component {
  componentDidMount() {
    this.props.dispatch({
      type: 'trade/fetchSnapshotList',
      payload: {},
    });
  }
  handleFilterOperation = (params) => {
    this.props.dispatch({
      type: 'trade/fetchSnapshotList',
      payload: params,
    });
  };
  handleBatchOperation = () => {
    Message.info('暂不支持批量操作!');
  };

  render() {
    const { trade, loading } = this.props;
    const { list, totalSize, pageSize, pageNo } = trade;

    const batchActions = [{
      key: 'delete',
      name: '批量处理',
    }];
    const basicSearch = {
      keys: [{
        name: '校区名称',
        field: 'campusName',
      }, {
        name: '校区编号',
        field: 'campusCode',
      }, {
        name: '终端编号',
        field: 'userCode',
      }, {
        name: '产品编号',
        field: 'productCode',
      }],
    };
    const pagination = {
      pageNo,
      pageSize,
      totalSize,
    };
    const columns = [{
      title: '产品信息',
      key: 1,
      width: '30%',
      render: (_, record) => {
        const { productCode, productName, productType } = record;
        return (
          <div className={styles.desc}>
            <p><span>产品编号:&nbsp;</span>{productCode}</p>
            <p><span>产品名称:&nbsp;</span>{productName}</p>
            <p><span>产品类型:&nbsp;</span>{renderProductType(productType)}</p>
          </div>
        );
      },
    }, {
      title: '用户信息',
      key: 2,
      width: '34%',
      render: (_, record) => {
        const { userCode, campusName, merchantName } = record;
        return (
          <div className={styles.desc}>
            <p><span>终端编号:&nbsp;</span>{userCode}</p>
            <p><span>所属校区:&nbsp;</span>{campusName}</p>
            <p><span>所属渠道:&nbsp;</span>{merchantName}</p>
          </div>
        );
      },
    }, {
      title: '价格信息',
      key: 3,
      render: (_, record) => {
        const { merchantPrice, chargeUnit, quantity } = record;
        return (
          <div className={styles.desc}>
            <p><span>商品价格:&nbsp;¥</span>{merchantPrice}</p>
            <p><span>计价单位:&nbsp;</span>{chargeUnit}</p>
            <p><span>购买数量:&nbsp;×</span>{quantity}</p>
          </div>
        );
      },
      width: '18%',
    }, {
      title: '购买时间',
      key: 4,
      dataIndex: 'gmtCreated',
      render: text => moment(text).format('YYYY-MM-DD HH:mm:ss'),
      width: '18%',
    }];
    return (
      <Card style={{ margin: 16 }}>
        <StandardTableList
          columns={columns}
          loading={loading}
          dataSource={addRowKey(list)}
          header={{
            basicSearch,
            onFilterClick: this.handleFilterOperation,
          }}
          footer={{
            pagination,
            batchActions,
            onBatchClick: this.handleBatchOperation,
          }}
          showStatusSelect={false}
        />
      </Card>
    );
  }
}
