/* eslint-disable react/no-unescaped-entities */
import React, { PureComponent } from 'react';
import { Card, Icon } from 'antd';
import DescriptionList from '../../components/DescriptionList';
import styles from './document.less';

const { Description } = DescriptionList;

const resourceQAList = [{
  question: '图片的创建与编辑',
  answer: '操作："基础资源 > 图片管理 > 新建/编辑"，正确填写图片的编号和名称后方可选择待上传图片;',
  note: '注意：图片编号应满足格式限制，不填写或者格式错误禁止上传图片',
  imgList: [
    'http://efunimgs.oss-cn-beijing.aliyuncs.com/resources/document/image/1/15279977811093052.png',
    'http://efunimgs.oss-cn-beijing.aliyuncs.com/resources/document/image/2/15280040674381093.png',
  ],
}, {
  question: '视频的创建与编辑',
  answer: '操作："基础资源 > 视频管理 > 新建/编辑"，正确填写视频相关信息',
  note: '注意：视频编号、名称、路径、类型、清晰度、格式为必填项',
  imgList: [
    'http://efunimgs.oss-cn-beijing.aliyuncs.com/resources/document/video/1/15280080455214642.png',
  ],
}, {
  question: '有声读物的创建与编辑',
  answer: '操作："基础资源 > 有声读物 > 新建/编辑"，正确填写有声读物的相关信息',
  note: '注意：有声读物编号、有声读物名称、音频路径、音频格式为必填项，上传图片有且仅支持一张图片的上传和选择',
  imgList: [
    'http://efunimgs.oss-cn-beijing.aliyuncs.com/resources/0000111/15290356776645389.png',
    'http://efunimgs.oss-cn-beijing.aliyuncs.com/resources/haha/15290357830402821.png',
  ],
}];
const productQAList = [{
  question: '课件的创建及编辑',
  answer: '操作："产品加工 > 制作课件 > 新建/编辑"，正确填写课件编号及名称等基础信息后，选择课件内容后排序',
  note: '注意：图片课件可包含多张图片资源，视频课件仅能包含一个视频资源，切勿图片与视频混选',
  imgList: [
    'http://efunimgs.oss-cn-beijing.aliyuncs.com/resources/document/ware/1/1528009377007865.png',
    'http://efunimgs.oss-cn-beijing.aliyuncs.com/resources/document/ware/2/15280107071076247.png',
  ],
}, {
  question: '课/课程/配套/师训/套餐包等创建及编辑',
  answer: '此种产品类型的加工过程请参照课件的创建过程',
}];
const shelvesQAList = [{
  question: '产品的上架流程',
  answer: '操作："产品出售 > 上架XX > 新建"，正确选择产品及对应渠道后，提交即可将产品上架到对应渠道',
  note: '注意：新建过程仅仅是将一个产品关联到某渠道，此时前端并未展现，需要再次编辑该产品挂载到相应栏目下，才可展现',
  imgList: [
    'http://efunimgs.oss-cn-beijing.aliyuncs.com/resources/document/shelves/1/15280127770612598.png',
    'http://efunimgs.oss-cn-beijing.aliyuncs.com/resources/document/shelves/2/15280127974934585.png',
  ],
}];
const frontConfig = [{
  question: '首页入口',
  answer: '操作："前端配置 > 首页入口 > 新建/编辑"，可以新建/编辑 标签组到对应的渠道',
  note: '在编辑页面找到该入口下 标签列表 表格，拖动或者点击进行排序，即可对该标签组下的标签进行排序',
  imgList: [
    'http://efunimgs.oss-cn-beijing.aliyuncs.com/resources/notes1/15290475537003780.png',
    'http://efunimgs.oss-cn-beijing.aliyuncs.com/resources/notes02/15290476539697182.png',
  ],
}, {
  question: '栏目类型',
  answer: '操作："前端配置 > 栏目类型 > 新建/编辑"，可以新建/编辑 标签类',
  note: '在编辑页面找到该入口下 标签列表 表格，拖动或者点击进行排序，即可对该标签类下的标签进行排序',
}, {
  question: '侧边栏目',
  answer: '操作："前端配置 > 侧边栏目 > 新建/编辑"，可以新建/编辑 标签',
  note: '在编辑页面找到该入口下 标签列表 表格，拖动或者点击进行排序，即可对该标签下的相关产品进行排序',
  imgList: [
    'http://efunimgs.oss-cn-beijing.aliyuncs.com/resources/notes003/15290489273706567.png',
    'http://efunimgs.oss-cn-beijing.aliyuncs.com/resources/notes004/15290489908065769.png',
  ],
}, {
  question: '推荐内容',
  answer: '操作："前端配置 > 推荐内容 > 课程/海报"，可以对 推荐位置 课程/海报 进行修改和设置',
  note: '从课程资源选取课程到推荐课程位置，从图片资源选取图片到 轮播图中的滚动海报位置',
  imgList: [
    'http://efunimgs.oss-cn-beijing.aliyuncs.com/resources/notes005/15290494850684261.png',
  ],
}];
const otherQAList = [{
  question: '欢迎联系开发组团队，我们将及时反馈您的问题 ╰(￣▽￣)╭',
  answer: '更多功能即将上线 d=====(￣▽￣*)b',
}];

function FAQComponent({ sort, bigTitle, qaList }) {
  return (
    <DescriptionList
      col={1}
      size="large"
      title={`${sort}.${bigTitle}`}
      className={styles.descList}
    >
      {/* eslint-disable react/no-array-index-key */}
      {
        qaList.map((qa, index) => {
          const { question, answer, note, imgList } = qa;
          return (
            <div key={index}>
              <Description>
                <Icon type="question-circle-o" className={styles.question} />&nbsp;{question}
              </Description>
              <Description>
                <Icon type="check-circle-o" className={styles.answer} />&nbsp;{answer}
                {note && (<div>&nbsp;&nbsp;&nbsp;&nbsp;{note}</div>)}
              </Description>
              {(imgList && imgList.length) && imgList.map((img, imgIndex) => (
                <Description key={imgIndex}>
                  <img src={img} alt="" style={{ width: '100%', height: 550 }} />
                </Description>
              ))}
            </div>
          );
        })
      }
    </DescriptionList>
  );
}

export default class PlatformDocument extends PureComponent {
  render() {
    return (
      <Card title="平台使用文档" className={styles.card}>
        <FAQComponent
          sort={1}
          bigTitle="资源管理"
          qaList={resourceQAList}
        />
        <FAQComponent
          sort={2}
          bigTitle="产品加工"
          qaList={productQAList}
        />
        <FAQComponent
          sort={3}
          bigTitle="产品出售"
          qaList={shelvesQAList}
        />
        <FAQComponent
          sort={4}
          bigTitle="前端配置"
          qaList={frontConfig}
        />
        <FAQComponent
          sort={5}
          bigTitle="其他问题"
          qaList={otherQAList}
        />
      </Card>
    );
  }
}
