import React, { Component } from 'react';
import pathToRegexp from 'path-to-regexp';
import { connect } from 'dva';
import { routerRedux } from 'dva/router';
import { message, Form, Table, Modal, Card, Button, Input, Switch, Radio } from 'antd';
import { statusToBool, boolToStatus } from '../../../utils/utils';
import AXDragSortTable from '../../../components/AXDragSortTable/index';
import Selector from '../../../components/AXTableSelector/Selector';
import FooterToolbar from '../../../components/FooterToolbar/index';
import styles from './TagCreate.less';

const Message = message;

const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 2 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 14 },
    md: { span: 12 },
  },
};

@connect(({ loading, tag, tagGroup, shelves, tagType, merchant }) => ({
  tag,
  shelves,
  tagGroup,
  tagType,
  merchant,
  submitting: loading.models.tag,
  sLoading: loading.models.shelves,
  mLoading: loading.models.merchant,
  tLoading: loading.models.tagGroup,
  ttLoading: loading.models.tagType,
}))
@Form.create()
export default class TagCreatePage extends Component {
  state = {
    tagTypeSelectorDestroy: true,
    tagGroupSelectorDestroy: true,
    merchantSelectorDestroy: true,
    shelvesSelectorDestroy: true,
    productType: 'Course',
  };
  componentWillMount() {
    this.props.dispatch({
      type: 'tag/cleanItemState',
      payload: {},
    });
  }
  componentDidMount() {
    const matchId = this.isEdit();
    if (matchId) {
      this.props.dispatch({
        type: 'tag/fetchTagItem',
        payload: { tagId: matchId },
      });
    }
  }
  isEdit = () => {
    const { location } = this.props;
    const match = pathToRegexp('/frontend/tag/edit/:id').exec(location.pathname);
    if (match) {
      return match[1];
    }
    return false;
  };
  handleRadioChange=(e) => {
    this.setState({ productType: e.target.value });
    this.selectorDataFetcher(e.target.value, {});
  };
  selectorDataFetcher=(name, params) => {
    switch (name) {
      case 'Course':
        this.props.dispatch({
          type: 'shelves/fetchCourseItemList',
          payload: params,
        });
        break;
      case 'Support':
        this.props.dispatch({
          type: 'shelves/fetchSupportItemList',
          payload: params,
        });
        break;
      case 'tagGroup':
        this.props.dispatch({
          type: 'tagGroup/fetchTagGroupList',
          payload: params,
        });
        break;
      case 'tagType':
        this.props.dispatch({
          type: 'tagType/fetchTagTypeList',
          payload: params,
        });
        break;
      case 'merchant':
        this.props.dispatch({
          type: 'merchant/fetchMerchantList',
          payload: params,
        });
        break;
      default:
        break;
    }
  };
  handleTagMetaSelectorModalShow = (flag) => {
    this.setState({
      [`${flag}SelectorDestroy`]: false,
    });
    this.selectorDataFetcher(flag);
  };
  handleTagMetaInfoSelectorChange = (flag, params) => {
    this.selectorDataFetcher(flag, params);
  };
  handleTagMetaInfoSelectorCancel = (flag) => {
    this.setState({
      [`${flag}SelectorDestroy`]: true,
    });
  };
  handleTagMetaInfoSelectorFinish = (flag, rows) => {
    this.setState({
      [`${flag}SelectorDestroy`]: true,
    });
    if (!rows || !rows.length) {
      return;
    }
    let payload;
    switch (flag) {
      case 'tagGroup':
        payload = { groupId: rows[0].id, groupName: rows[0].name };
        break;
      case 'tagType':
        payload = { typeCode: rows[0].code };
        break;
      case 'merchant':
        payload = { merchantId: rows[0].id, merchantName: rows[0].name };
        break;
      default:
        break;
    }
    this.props.dispatch({
      type: 'tag/fixCurrentItem',
      payload,
    });
  };
  handleShelvesSelectorModalShow = () => {
    const { tag } = this.props;
    const { currentItem } = tag;
    const { merchantId } = currentItem;
    if (!merchantId) {
      Message.error('请先选择标签所属的渠道!');
      return;
    }
    const params = { merchantId };
    this.setState({
      shelvesSelectorDestroy: false,
    });
    this.selectorDataFetcher(this.state.productType, params);
  };
  handleShelvesSelectorChange = (params) => {
    const { tag } = this.props;
    const { currentItem } = tag;
    const { merchantId } = currentItem;
    this.selectorDataFetcher(this.state.productType, { ...params, merchantId });
  };
  handleShelvesSelectorCancel = () => {
    this.setState({
      shelvesSelectorDestroy: true,
    });
  };
  handleShelvesSelectorFinish = (rows) => {
    this.setState({
      shelvesSelectorDestroy: true,
    });
    if (!rows || !rows.length) {
      return;
    }
    this.props.dispatch({
      type: 'tag/fixCurrentItem',
      payload: { productList: rows },
    });
  };
  handleDragSortTableChange = (rows) => {
    this.props.dispatch({
      type: 'tag/fixCurrentItem',
      payload: { productList: rows },
    });
  };
  handlePageBack = () => {
    this.props.dispatch(routerRedux.push({
      pathname: '/frontend/tag',
      state: this.props.location.state,
    }));
  };
  handlePageSubmit = (e) => {
    e.preventDefault();
    this.props.form.validateFieldsAndScroll((err, values) => {
      if (!err) {
        const { name, status } = values;
        const { tag } = this.props;
        const { currentItem } = tag;
        const { productList = [], groupId, typeCode } = currentItem;
        const id = this.isEdit();
        if (id) {
          this.props.dispatch({
            type: 'tag/updateTagItem',
            payload: {
              id,
              name,
              groupId,
              typeCode,
              status: boolToStatus(status),
              productList: productList.map(item => item.pid),
            },
            states: this.props.location.state,
          });
        } else {
          this.props.dispatch({
            type: 'tag/createTagItem',
            payload: {
              name,
              groupId,
              typeCode,
              status: boolToStatus(status),
              productList: productList.map(item => item.pid),
            },
            states: this.props.location.state,
          });
        }
      }
    });
  };

  render() {
    const {
      form, submitting, mLoading, tLoading, ttLoading,
      sLoading, shelves, tag, tagGroup, tagType, merchant,
    } = this.props;
    const {
      shelvesSelectorDestroy, tagGroupSelectorDestroy,
      merchantSelectorDestroy, tagTypeSelectorDestroy, productType,
    } = this.state;
    const { currentItem } = tag;
    const { status, typeCode, name, groupName, merchantName, productList = [] } = currentItem;
    const { getFieldDecorator } = form;

    const tagMetaData = [{
      fieldName: '所属类型:',
      value: typeCode,
      key: 'tagType',
    }, {
      fieldName: '所属标签组:',
      value: groupName,
      key: 'tagGroup',
    }, {
      fieldName: '所属渠道:',
      value: merchantName,
      key: 'merchant',
    }];
    const tagMetaColumns = [{
      dataIndex: 'fieldName',
      key: 1,
      width: '10%',
      align: 'left',
      render: (text, record) => (
        <Button
          size="small"
          type="primary"
          style={{ width: 90 }}
          onClick={() => this.handleTagMetaSelectorModalShow(record.key)}
        >{text}
        </Button>
      ),
    }, {
      dataIndex: 'value',
      key: 2,
      width: '90%',
    }];
    const productColumns = [{
      title: '产品编号',
      dataIndex: 'code',
      key: 1,
      width: '35%',
    }, {
      title: '产品名称',
      dataIndex: 'name',
      key: 2,
    }];
    const renderProductModalTitle = () => {
      return (
        <Radio.Group
          value={productType}
          onChange={this.handleRadioChange}
          className={styles.radio}
        >
          <Radio.Button value="Course">课程</Radio.Button>
          <Radio.Button value="Support">配套</Radio.Button>
        </Radio.Group>
      );
    };
    const getTagTypeModal = () => {
      return (
        <Modal
          width={1100}
          footer={null}
          visible
          title="标签类别"
          maskClosable={false}
          onCancel={() => this.handleTagMetaInfoSelectorCancel('tagType')}
        >
          <Selector
            multiple={false}
            loading={ttLoading}
            selectorName="TagType"
            list={tagType.list}
            pageNo={tagType.pageNo}
            pageSize={tagType.pageSize}
            totalSize={tagType.totalSize}
            onCancel={() => this.handleTagMetaInfoSelectorCancel('tagType')}
            onChange={data => this.handleTagMetaInfoSelectorChange('tagType', data)}
            onFinish={data => this.handleTagMetaInfoSelectorFinish('tagType', data)}
          />
        </Modal>
      );
    };
    const getTagGroupModal = () => {
      return (
        <Modal
          width={1100}
          footer={null}
          visible
          title="标签组"
          maskClosable={false}
          onCancel={() => this.handleTagMetaInfoSelectorCancel('tagGroup')}
        >
          <Selector
            multiple={false}
            loading={tLoading}
            selectorName="TagGroup"
            list={tagGroup.list}
            pageNo={tagGroup.pageNo}
            pageSize={tagGroup.pageSize}
            totalSize={tagGroup.totalSize}
            onCancel={() => this.handleTagMetaInfoSelectorCancel('tagGroup')}
            onChange={data => this.handleTagMetaInfoSelectorChange('tagGroup', data)}
            onFinish={data => this.handleTagMetaInfoSelectorFinish('tagGroup', data)}
          />
        </Modal>
      );
    };
    const getMerchantModal = () => {
      return (
        <Modal
          width={1100}
          footer={null}
          visible
          title="渠道列表"
          maskClosable={false}
          onCancel={() => this.handleTagMetaInfoSelectorCancel('merchant')}
        >
          <Selector
            multiple={false}
            loading={mLoading}
            selectorName="Merchant"
            list={merchant.list}
            pageNo={merchant.pageNo}
            pageSize={merchant.pageSize}
            totalSize={merchant.totalSize}
            onCancel={() => this.handleTagMetaInfoSelectorCancel('merchant')}
            onChange={data => this.handleTagMetaInfoSelectorChange('merchant', data)}
            onFinish={data => this.handleTagMetaInfoSelectorFinish('merchant', data)}
          />
        </Modal>
      );
    };
    const getProductModal = () => {
      return (
        <Modal
          width={1100}
          footer={null}
          visible
          title={renderProductModalTitle()}
          maskClosable={false}
          onCancel={this.handleShelvesSelectorCancel}
        >
          <Selector
            multiple
            loading={sLoading}
            selectorName={productType}
            list={shelves.list}
            pageNo={shelves.pageNo}
            pageSize={shelves.pageSize}
            totalSize={shelves.totalSize}
            onCancel={this.handleShelvesSelectorCancel}
            onChange={this.handleShelvesSelectorChange}
            onFinish={this.handleShelvesSelectorFinish}
          />
        </Modal>
      );
    };
    const renderProductCardName = () => {
      return (
        <Button type="primary" onClick={this.handleShelvesSelectorModalShow}>关联产品</Button>
      );
    };
    return (
      <div>
        {/* 基础信息Card */}
        <Card title="基础信息" style={{ marginBottom: 16 }}>
          <Form>
            <Form.Item hasFeedback label="标签名称" {...formItemLayout}>
              {getFieldDecorator('name', {
                rules: [{ required: true, message: '请填写标签名称' }],
                initialValue: name,
              })(
                <Input placeholder="请输入" />
              )}
            </Form.Item>
            <Form.Item label="标签状态" {...formItemLayout}>
              {getFieldDecorator('status', {
                valuePropName: 'checked',
                initialValue: statusToBool(status),
              })(
                <Switch checkedChildren="正常" unCheckedChildren="删除" />
              )}
            </Form.Item>
          </Form>
        </Card>
        {/* 标签类别信息选择Card */}
        <Card title="类别信息" style={{ marginBottom: 16 }}>
          <Table
            bordered
            size="small"
            showHeader={false}
            pagination={false}
            columns={tagMetaColumns}
            dataSource={tagMetaData}
          />
          {!tagGroupSelectorDestroy && getTagGroupModal()}
          {!tagTypeSelectorDestroy && getTagTypeModal()}
          {!merchantSelectorDestroy && getMerchantModal()}
        </Card>
        {/* 产品选择Card */}
        <Card title={renderProductCardName()} style={{ marginBottom: 70 }}>
          <AXDragSortTable
            data={productList}
            columns={productColumns}
            onChange={this.handleDragSortTableChange}
          />
          {!shelvesSelectorDestroy && getProductModal()}
        </Card>
        <FooterToolbar style={{ width: '100%' }}>
          <Button
            onClick={this.handlePageBack}
            style={{ marginRight: 10 }}
          >取消
          </Button>
          <Button
            type="primary"
            loading={submitting}
            onClick={this.handlePageSubmit}
          >提交
          </Button>
        </FooterToolbar>
      </div>
    );
  }
}
