import React, { Component } from 'react';
import moment from 'moment';
import { connect } from 'dva';
import { routerRedux } from 'dva/router';
import { Card, Modal, Button, message } from 'antd';
import { StandardTableList } from '../../../components/AXList/index';
import { renderStatus, addRowKey } from '../../../utils/utils';

const Message = message;

@connect(({ loading, tag }) => ({
  tag,
  loading: loading.models.tag,
}))
export default class TagListPage extends Component {
  constructor(props) {
    super(props);
    const { state } = props.location;
    this.state = {
      UIParams: (state || {}).UIParams, // 组件的状态参数
      Queryers: (state || {}).Queryers, // 查询的条件参数
    };
  }
  componentDidMount() {
    this.props.dispatch({
      type: 'tag/fetchTagList',
      payload: { ...this.state.Queryers },
    });
  }
  handleCreateOperation = () => {
    this.props.dispatch(routerRedux.push({
      pathname: '/frontend/tag/create',
      state: this.state,
    }));
  };
  handleDeleteOperation = (item) => {
    Modal.confirm({
      okText: '确定',
      cancelText: '取消',
      title: '你确定要删除该标签吗?',
      onOk: () => {
        this.props.dispatch({
          type: 'tag/deleteTagItem',
          payload: { tagId: item.id },
          states: this.state,
        });
      },
    });
  };
  handleEditOperation = (item) => {
    this.props.dispatch(routerRedux.push({
      pathname: `/frontend/tag/edit/${item.id}`,
      state: this.state,
    }));
  };
  handleFilterOperation = (params, states) => {
    this.props.dispatch({
      type: 'tag/fetchTagList',
      payload: params,
    });
    this.setState({
      UIParams: states,
      Queryers: params,
    });
  };
  handleBatchOperation = () => {
    Message.info('暂不支持批量操作!');
  };

  render() {
    const { loading, tag } = this.props;
    const { list, totalSize, pageSize, pageNo } = tag;

    const renderOperation = (item) => {
      return (
        <div>
          <Button
            size="small"
            className="editBtn"
            onClick={() => this.handleEditOperation(item)}
          >编辑
          </Button>
          <Button
            size="small"
            className="delBtn"
            onClick={() => this.handleDeleteOperation(item)}
          >删除
          </Button>
        </div>
      );
    };

    const batchActions = [{
      key: 'delete',
      name: '批量删除',
    }, {
      key: 'recovery',
      name: '批量恢复',
    }];
    const basicSearch = {
      keys: [{
        name: '标签名称',
        field: 'name',
      }],
    };
    const pagination = {
      pageNo,
      pageSize,
      totalSize,
    };
    const columns = [{
      title: '标签名称',
      key: 1,
      dataIndex: 'name',
      width: '15%',
    }, {
      title: '标签类型',
      key: 2,
      dataIndex: 'typeCode',
      width: '15%',
    }, {
      title: '所属标签组',
      key: 3,
      dataIndex: 'groupName',
      width: '15%',
    }, {
      title: '所属渠道',
      key: 4,
      dataIndex: 'merchantName',
      width: '12%',
    }, {
      title: '标签状态',
      key: 5,
      dataIndex: 'status',
      render: text => renderStatus(text),
      width: '10%',
    }, {
      title: '更新时间',
      key: 6,
      dataIndex: 'gmtModified',
      render: text => moment(text).format('YYYY-MM-DD HH:mm:ss'),
      width: '15%',
    }, {
      title: '操作',
      key: 7,
      render: (_, record) => renderOperation(record),
      width: '13%',
      align: 'right',
    }];
    return (
      <Card>
        <StandardTableList
          columns={columns}
          loading={loading}
          dataSource={addRowKey(list)}
          header={{
            basicSearch,
            onFilterClick: this.handleFilterOperation,
            onCreateClick: this.handleCreateOperation,
          }}
          footer={{
            pagination,
            batchActions,
            onBatchClick: this.handleBatchOperation,
          }}
          keepUIState={{ ...this.state.UIParams }}
        />
      </Card>
    );
  }
}
