/* eslint-disable prefer-destructuring */
import React, { Component } from 'react';
import pathToRegexp from 'path-to-regexp';
import { connect } from 'dva';
import { routerRedux } from 'dva/router';
import { Form, Modal, Card, Button, Input, Switch, Divider } from 'antd';
import { renderStatus, statusToBool, boolToStatus } from '../../../utils/utils';
import AXDragSortTable from '../../../components/AXDragSortTable';
import Selector from '../../../components/AXTableSelector/Selector';
import FooterToolbar from '../../../components/FooterToolbar';

const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 3 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 14 },
    md: { span: 12 },
  },
};

/**
 * 根据渠道id过滤标签
 * @param merchantId
 * @param tagList
 */
const filterTagListByMerchantId = (merchantId, tagList) => {
  if (!merchantId) { return tagList; }
  return tagList.filter(tag => tag.merchantId === merchantId);
};
/**
 * 根据子数组顺序调整父数组
 * @param subArray
 * @param parentArray
 */
const arraySort = (subArray = [], parentArray = []) => {
  let cursor = 0;
  const newArray = [...parentArray];
  while (cursor < subArray.length - 1) {
    const prevId = subArray[cursor].id;
    const nextId = subArray[cursor + 1].id;
    const currentIndex = newArray.findIndex(data => data.id === prevId);
    const targetIndex = newArray.findIndex(data => data.id === nextId);
    if (currentIndex > targetIndex) {
      newArray[currentIndex] = newArray.splice(targetIndex, 1, newArray[currentIndex])[0];
    }
    cursor += 1;
  }
  return newArray;
};

@connect(({ loading, tagType, merchant }) => ({
  tagType,
  merchant,
  submitting: loading.models.tagType,
  mLoading: loading.models.merchant,
}))
@Form.create()
export default class TagTypeCreatePage extends Component {
  state = {
    merchantSelectorDestroy: true,
    currentMerchantId: '',
    currentMerchantName: '全部',
  };
  componentWillMount() {
    this.props.dispatch({
      type: 'tagType/cleanItemState',
      payload: {},
    });
  }
  componentDidMount() {
    const matchId = this.isEdit();
    if (matchId) {
      this.props.dispatch({
        type: 'tagType/fetchTagTypeItem',
        payload: { tagTypeId: matchId },
      });
    }
  }
  isEdit = () => {
    const { location } = this.props;
    const match = pathToRegexp('/frontend/tagType/edit/:id').exec(location.pathname);
    if (match) {
      return match[1];
    }
    return false;
  };
  selectorDataFetcher = (name, params) => {
    switch (name) {
      case 'Merchant':
        this.props.dispatch({
          type: 'merchant/fetchMerchantList',
          payload: params,
        });
        break;
      case 'Tag':
        this.props.dispatch({
          type: 'tag/fetchTagList',
          payload: params,
        });
        break;
      default:
        break;
    }
  };
  handleMerchantSelectorModalShow = () => {
    this.setState({
      merchantSelectorDestroy: false,
    });
    this.selectorDataFetcher('Merchant');
  };
  handleMerchantSelectorChange = (params) => {
    this.selectorDataFetcher('Merchant', params);
  };
  handleMerchantSelectorCancel = () => {
    this.setState({
      merchantSelectorDestroy: true,
    });
  };
  handleMerchantSelectorFinish = (rows) => {
    if (!rows || !rows.length) {
      return;
    }
    const { id, name } = rows[0];
    this.setState({
      currentMerchantId: id,
      currentMerchantName: name,
      merchantSelectorDestroy: true,
    });
  };
  handleDragSortTableChange = (rows) => {
    const { currentItem } = this.props.tagType;
    const { tagList } = currentItem;
    this.props.dispatch({
      type: 'tagType/fixCurrentItem',
      payload: { tagList: arraySort(rows || [], tagList || []) },
    });
  };
  handlePageBack = () => {
    this.props.dispatch(routerRedux.push({
      pathname: '/frontend/tagType',
      state: this.props.location.state,
    }));
  };
  handlePageSubmit = (e) => {
    e.preventDefault();
    this.props.form.validateFieldsAndScroll((err, values) => {
      if (!err) {
        const { code, name, status } = values;
        const { tagType } = this.props;
        const { currentItem } = tagType;
        const { tagList = [], merchantId } = currentItem;
        const id = this.isEdit();
        if (id) {
          this.props.dispatch({
            type: 'tagType/updateTagTypeItem',
            payload: {
              id,
              code,
              name,
              merchantId,
              status: boolToStatus(status),
              tagList: tagList.map(item => item.id),
            },
            states: this.props.location.state,
          });
        } else {
          this.props.dispatch({
            type: 'tagType/createTagTypeItem',
            payload: {
              code,
              name,
              merchantId,
              status: boolToStatus(status),
              tagList: tagList.map(item => item.id),
            },
            states: this.props.location.state,
          });
        }
      }
    });
  };

  render() {
    const { form, submitting, mLoading, merchant, tagType } = this.props;
    const { merchantSelectorDestroy, currentMerchantId, currentMerchantName } = this.state;
    const { currentItem } = tagType;
    const { status, code, name, tagList = [] } = currentItem;
    const { getFieldDecorator } = form;

    const tagColumns = [{
      title: '标签名称',
      dataIndex: 'name',
      key: 1,
      width: '35%',
    }, {
      title: '标签状态',
      dataIndex: 'status',
      render: text => renderStatus(text),
      key: 2,
    }];
    const getMerchantModal = () => {
      return (
        <Modal
          width={1100}
          footer={null}
          visible
          title="渠道列表"
          maskClosable={false}
          onCancel={this.handleMerchantSelectorCancel}
        >
          <Selector
            multiple={false}
            loading={mLoading}
            selectorName="Merchant"
            list={merchant.list}
            pageNo={merchant.pageNo}
            pageSize={merchant.pageSize}
            totalSize={merchant.totalSize}
            onCancel={this.handleMerchantSelectorCancel}
            onChange={this.handleMerchantSelectorChange}
            onFinish={this.handleMerchantSelectorFinish}
          />
        </Modal>
      );
    };
    return (
      <div>
        {/* 基础信息Card */}
        <Card title="基础信息" style={{ marginBottom: 16 }}>
          <Form>
            <Form.Item hasFeedback label="标签类型编号" {...formItemLayout}>
              {getFieldDecorator('code', {
                rules: [
                  {
                    required: true, message: '请填写标签类型编号',
                  }, {
                    pattern: /^[a-zA-Z0-9_-]+$/g, message: '编号包含非法字符',
                  },
                ],
                initialValue: code,
              })(
                <Input
                  placeholder="请输入"
                  disabled={!!this.isEdit()}
                />
              )}
            </Form.Item>
            <Form.Item hasFeedback label="标签类型名称" {...formItemLayout}>
              {getFieldDecorator('name', {
                rules: [{ required: true, message: '请填写标签类型名称' }],
                initialValue: name,
              })(
                <Input placeholder="请输入" />
              )}
            </Form.Item>
            <Form.Item label="标签类型状态" {...formItemLayout}>
              {getFieldDecorator('status', {
                valuePropName: 'checked',
                initialValue: statusToBool(status),
              })(
                <Switch checkedChildren="正常" unCheckedChildren="删除" />
              )}
            </Form.Item>
          </Form>
        </Card>
        {/* 标签排序Card */}
        {this.isEdit() && (
          <Card
            title={
              <div>
                <span>标签列表</span>
                <Divider type="vertical" />
                <Button
                  type="primary"
                  size="small"
                  style={{ width: 100 }}
                  onClick={this.handleMerchantSelectorModalShow}
                >{currentMerchantName}
                </Button>
              </div>
            }
            style={{ marginBottom: 70 }}
          >
            <AXDragSortTable
              data={filterTagListByMerchantId(currentMerchantId, tagList)}
              columns={tagColumns}
              onChange={this.handleDragSortTableChange}
            />
            {!merchantSelectorDestroy && getMerchantModal()}
          </Card>
        )}
        <FooterToolbar style={{ width: '100%' }}>
          <Button
            onClick={this.handlePageBack}
            style={{ marginRight: 10 }}
          >取消
          </Button>
          <Button
            type="primary"
            loading={submitting}
            onClick={this.handlePageSubmit}
          >提交
          </Button>
        </FooterToolbar>
      </div>
    );
  }
}
