/* eslint-disable no-prototype-builtins */
import React, { Component } from 'react';
import { connect } from 'dva';
import { routerRedux } from 'dva/router';
import { Card, Modal, Button, message } from 'antd';
import VideoPlayList from './VideoPlayList';
import VideoTableList from './VideoTableList';
import PageHeaderLayout from '../../../layouts/PageHeaderLayout';
import { addRowKey } from '../../../utils/utils';

const Message = message;

function deleteBlankKey(obj) {
  if (!(typeof obj === 'object')) {
    return;
  }
  const newObj = { ...obj };
  for (const key in newObj) {
    if (newObj.hasOwnProperty(key) && !newObj[key]) {
      delete newObj[key];
    }
  }
  return newObj;
}

@connect(({ loading, resource }) => ({
  resource,
  loading: loading.models.resource,
}))
export default class VideoListPage extends Component {
  constructor(props) {
    super(props);
    const { state } = props.location;
    this.state = {
      isCard: false,
      destroy: true,
      current: {},
      UIParams: (state || {}).UIParams, // 组件的状态参数
      Queryers: (state || {}).Queryers, // 查询的条件参数
    };
  }
  componentWillMount() {
    this.props.dispatch({
      type: 'resource/clearState',
    });
  }
  componentDidMount() {
    this.props.dispatch({
      type: 'resource/fetchVideoList',
      payload: { ...this.state.Queryers },
    });
  }
  handleShowTypeChange = () => {
    this.setState({ isCard: !this.state.isCard });
  };
  handleModalDestroy = () => {
    this.setState({ destroy: true });
  };
  handleModalCreate = (item) => {
    this.setState({ destroy: false, current: item });
  };
  // 创建视频(增)
  handleCreateOperation = () => {
    const { UIParams, Queryers } = this.state;
    this.props.dispatch(
      routerRedux.push({
        pathname: '/resource/video-create',
        state: { UIParams, Queryers },
      })
    );
  };
  // 删除视频(删)
  handleDeleteOperation = (item) => {
    Modal.confirm({
      okText: '确定',
      cancelText: '取消',
      title: '您确定要删除该视频吗?',
      onOk: () => {
        this.props.dispatch({
          type: 'resource/deleteVideo',
          payload: { id: item.id },
        });
      },
    });
  };
  // 修改视频(改)
  handleUpdateOperation = (item) => {
    const { UIParams, Queryers } = this.state;
    this.props.dispatch(
      routerRedux.push({
        pathname: `/resource/video-edit/${item.id}`,
        state: { UIParams, Queryers, ...item },
      })
    );
  };
  // 查询视频(查)
  handleFilterOperation = (params, states) => {
    const newParams = deleteBlankKey(params);
    this.props.dispatch({
      type: 'resource/fetchVideoList',
      payload: newParams,
    });
    this.setState({
      UIParams: states,
      Queryers: newParams,
    });
  };
  // TODO: 批量操作
  handleBatchOperation = () => {
    Message.info('暂不支持批量操作!');
  };

  render() {
    const { UIParams } = this.state;
    const { loading, resource } = this.props;
    const { list, totalSize, pageSize, pageNo } = resource;
    const publicProps = {
      loading,
      pageNo,
      pageSize,
      totalSize,
      UIParams,
      dataSource: addRowKey(list),
      onCreateClick: this.handleCreateOperation,
      onDeleteClick: this.handleDeleteOperation,
      onUpdateClick: this.handleUpdateOperation,
      onFilterClick: this.handleFilterOperation,
    };
    return (
      <PageHeaderLayout>
        <Card bordered={false}>
          <Button.Group style={{ marginBottom: 16 }}>
            <Button
              style={{ width: 50 }}
              onClick={this.handleShowTypeChange}
              icon="appstore-o"
              type={this.state.isCard ? 'primary' : null}
            />
            <Button
              style={{ width: 50 }}
              onClick={this.handleShowTypeChange}
              icon="table"
              type={this.state.isCard ? null : 'primary'}
            />
          </Button.Group>
          {this.state.isCard ?
            (<VideoPlayList {...publicProps} />)
            : (
              <VideoTableList
                {...publicProps}
                currentItem={this.state.current}
                modalDestroy={this.state.destroy}
                onModalDestroy={this.handleModalDestroy}
                onModalCreate={this.handleModalCreate}
                onBatchClick={this.handleBatchOperation}
              />
            )
          }
        </Card>
      </PageHeaderLayout>
    );
  }
}
