/* eslint-disable prefer-destructuring */
import React, { Component } from 'react';
import moment from 'moment';
import { connect } from 'dva';
import { Card, Badge, message } from 'antd';
import { StandardTableList } from '../../../components/AXList';
import Ellipsis from '../../../components/Ellipsis';
import { addRowKey } from '../../../utils/utils';
import styles from './AuthList.less';

const Message = message;

const timestamp2Str = ts => moment(ts).format('YYYY-MM-DD HH:mm:ss');

@connect(({ terminal, loading }) => ({
  terminal,
  loading: loading.models.terminal,
}))

export default class TerminalAuthListPage extends Component {
  constructor(props) {
    super(props);
    const { state } = props.location;
    this.state = {
      UIParams: (state || {}).UIParams, // 组件的状态参数
      Queryers: (state || {}).Queryers, // 查询的条件参数
    };
  }
  componentWillMount() {
    this.props.dispatch({
      type: 'terminal/cleanState',
    });
  }
  componentDidMount() {
    this.props.dispatch({
      type: 'terminal/fetchTerminalAuthList',
      payload: { ...this.state.Queryers },
    });
  }
  handleFilterOperation = (params, states) => {
    this.props.dispatch({
      type: 'terminal/fetchTerminalAuthList',
      payload: params,
    });
    this.setState({
      UIParams: states,
      Queryers: params,
    });
  };
  handleBatchOperation = () => {
    Message.info('暂不支持批量操作!');
  };
  render() {
    const { terminal, loading } = this.props;
    const { pageNo, pageSize, totalSize, list } = terminal;
    const basicSearch = {
      keys: [{
        name: '终端编号',
        field: 'code',
      }],
    };
    const batchActions = [{
      key: 'delete',
      name: '批量删除',
    }];
    const pagination = {
      pageNo,
      pageSize,
      totalSize,
    };
    const columns = [{
      title: '终端编号',
      key: 1,
      dataIndex: 'ucode',
      width: '15%',
      render: text => (
        <Ellipsis tooltip lines={1}>{text}</Ellipsis>
      ),
    }, {
      title: '产品编号',
      key: 2,
      dataIndex: 'pcode',
      width: '15%',
      render: text => (
        <Ellipsis tooltip lines={1}>{text}</Ellipsis>
      ),
    }, {
      title: '产品名称',
      key: 3,
      dataIndex: 'pname',
      width: '18%',
      render: text => (
        <Ellipsis tooltip lines={1}>{text}</Ellipsis>
      ),
    }, {
      title: '权限有效期',
      key: 4,
      render: (_, record) => {
        const {startTime, endTime} = record;
        return (
          <div className={styles.authDesc}>
            <p><span>起始时间:&nbsp;&nbsp;</span>{`${timestamp2Str(startTime)}`}</p>
            <p><span>到期时间:&nbsp;&nbsp;</span>{`${timestamp2Str(endTime)}`}</p>
          </div>
        );
      },
      width: '25%',
      align: 'center',
    }, {
      title: '权限有效时长',
      key: 5,
      dataIndex: 'endTime',
      render: (text) => {
        const day = moment(text).diff(moment(), 'days');
        if (day < 0) {
          return <Badge status="error" text="已到期" />;
        }
        return <span><span style={{ color: '#52c41a', fontWeight: 'bold' }}>{day}</span>天到期</span>;
      },
      width: '12%',
      align: 'center',
    }, {
      title: '修改时间',
      key: 6,
      dataIndex: 'updateTime',
      render: text => timestamp2Str(text),
      width: '15%',
      align: 'center',
    }];
    return (
      <Card>
        <StandardTableList
          columns={columns}
          loading={loading}
          dataSource={addRowKey(list)}
          header={{
            basicSearch,
            onFilterClick: this.handleFilterOperation,
          }}
          footer={{
            pagination,
            batchActions,
            onBatchClick: this.handleBatchOperation,
          }}
          keepUIState={{ ...this.state.UIParams }}
          showStatusSelect={false}
        />
      </Card>
    );
  }
}
