import { stringify } from 'qs';
import request from '../utils/request';
import { api, Hotax } from '../utils/config';

export async function queryTerminalBuyMsg(params) {
  return request(`${api.shopCart}?${stringify(params)}`);
}

export async function queryOrderList(params) {
  const newParams = {
    pageSize: Hotax.PAGE_SIZE,
    ...params,
  };
  return request(`${api.order}?${stringify(newParams)}`);
}

export async function querySnapshotList(params) {
  const newParams = {
    pageSize: Hotax.PAGE_SIZE,
    ...params,
  };
  return request(`${api.snapshot}?${stringify(newParams)}`);
}

export async function queryOrderItem({ id }) {
  return request(`${api.order}/${id}`);
}

export async function querySubOrderItem({ id }) {
  return request(`${api.subOrder}/${id}`);
}

export async function createOrderItem(params) {
  const options = {
    method: 'POST',
    body: params,
  };
  return request(`${api.order}`, options);
}

export async function invalidOrderItem({ id }) {
  const options = { method: 'DELETE' };
  return request(`${api.order}/${id}`, options);
}

export async function payOrderItem({ id }) {
  const options = { method: 'POST' };
  return request(`${api.orderPay}/${id}`, options);
}

export async function sendOrderItem({ id, ...restProps }) {
  const options = {
    method: 'POST',
    body: restProps,
  };
  return request(`${api.orderSend}/${id}`, options);
}

export async function receiveOrderItem({ id }) {
  const options = { method: 'POST' };
  return request(`${api.orderReceive}/${id}`, options);
}
